/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2020. All rights reserved.
 */
//
//  IdeaShareServiceController.h
//  ideaShareSDK_ios
//
//  Created by huawei on 2021/1/21.
//  Copyright © 2021 huawei. All rights reserved.
//

#ifndef IdeaShareServiceController_h
#define IdeaShareServiceController_h

#import<Foundation/Foundation.h>
#import "IdeaShareEventHandler.h"

NS_ASSUME_NONNULL_BEGIN
typedef void (^callback)(id t);
@interface IdeaShareServiceController : NSObject

@property(nonatomic, copy) callback discoverCallback;
@property(nonatomic, copy) callback connectCallback;
@property(nonatomic, copy) callback disconnectCallback;
@property(nonatomic, copy) callback starSharingCallback;
@property(nonatomic, copy) callback stopSharingCallback;
@property(nonatomic, copy) callback remoteServiceStatusCallback;
@property(nonatomic, copy) callback micMuteCallback;
@property(nonatomic, copy) callback speakerVolumeCallback;
@property(nonatomic, copy) callback speakerMuteCallback;
@property(nonatomic, copy) callback cameraMuteCallback;
@property(nonatomic, copy) callback leaveConfCallback;
@property(nonatomic, copy) callback finishConfCallback;
@property(nonatomic, copy) callback sdkLatestVersionCallback;
@property(nonatomic, copy) callback tlsCallback;
@property(weak)id<IdeaShareEventHandler> notifyDelegate;
@property(nonatomic, assign) float currentVolume;
@property(nonatomic, assign) BOOL isShareScreen;
@property(nonatomic, assign) BOOL isConnected;
@property(nonatomic, assign) int addNum;
@property(nonatomic, assign) int hubVolume;
@property(nonatomic, assign) BOOL isShareAudio;

+ (instancetype)shareInstance;
- (void)notifyCallback:(int)msgid :(int)param1 :(int)param2 :(const void *)data;
- (int)create:(const IdeaShareServiceAppInfo *)appInfo;
- (int)destroy;
- (int)setLog:(IdeaShareServiceLogInfo *)logInfo;
- (int)discover:(NSString *)castCode withAddress:(NSString *)address withPort:(int)port
    callback:(callback)discovercallback;
- (int)connect:(NSMutableArray *)addressList withPort:(int)port withPassword:(NSString *)password
    callback:(callback)connectcallback;
- (int)disconnect:(callback)disconnectcallback;
- (int)setPolicy:(SharePolicy *)sharePolicy;
- (int)getRemoteServiceStatus:(callback)remoteServiceStatuscallback;
- (int)setRemoteMicMute:(bool)isMute callback:(callback)micMutecallback;
- (int)setRemoteSpeakerMute:(bool)isSpeakerMute callback:(callback)speakerMutecallback;
- (int)setRemoteCameraMute:(bool)isCameraMute callback:(callback)cameraMutecallback;
- (int)setSpeakerVolume:(int)volume callback:(callback)volumecallback;
- (int)leaveConference:(callback)leaveConferencecallback;
- (int)finishConference:(callback)finishConferencecallback;
- (NSString *)getSDKVersion;
- (int)getSDKLatestVersion:(callback)sdkLatestVersioncallback;
- (void)volumeChanged:(NSNotification *)noti;
- (void)initDataBuffer:(NSString *)groupId;
- (int)startSharing:(callback)startSharingCallBack;
- (void)stopSharing:(callback)stopSharingCallBack;
- (int)setTls:(IdeaShareServiceTlsInfo *)tlsInfo callback:(callback)tlsCallback;
@end

NS_ASSUME_NONNULL_END
#endif
